function [Z, N, varargout] = autoNdGrid(N, d)
% [Z, N] = AUTONDGRID(N, d) returns a uniform grid in [-1, 1] ^ d consisting 
% of approximately N points. The actual number of points is returned.
% If d == 2, the function optionally returns 
%   varargout{1} = xx, 
%   varargout{2} = yy,
% with X = [xx(:), yy(:)] (useful for surf plotting).
%
% WARNING: the final N may be much larger than the input N if d is large.

box = repmat([-1 1], d, 1);

n = ceil(N ^ (1 / d));
x = linspace(-1, 1, n)';


ndArgs = cell(d, 1);
for j = 1 : d
    ndArgs{j} = x * (box(j, 2) - box(j, 1)) / 2 + (box(j, 2) + box(j, 1)) / 2;
end

[Z{1 : d}] = ndgrid(ndArgs{:});
if nargout == 4 && d == 2
    varargout{1} = Z{1}; % xx
    varargout{2} = Z{2}; % yy
end
Z = cat(d + 1, Z{:});
Z = reshape(Z, [], d);
N = size(Z, 1);

end