function f = kernelModel(x, varargin)
% f = KERNELMODEL(x, varargin) evaluates a kernel model.
%   f = KERNELMODEL(x, par) evaluates the kernel model defined by the
%   structure par on the Nxd dimensional point x and returns the Nxq
%   dimensional result f (one point per row).
%   The par structure needs to be passed as input only at the first call of
%   the function.

persistent par
if nargin > 1
    par = varargin{1};
    par.rbf = str2func(par.rbf);
end

x = bsxfun(@rdivide, bsxfun(@minus, x, par.translX), par.scaleX);
f = par.rbf(par.ep, distanceMatrix(x, par.X)) * par.a;
f = bsxfun(@plus, bsxfun(@times, f, par.scaleF), par.translF);

end